@@ -15,7 +15,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.8.3"
+__version__ = "0.8.4"
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -1125,7 +1125,8 @@ class SAM(object):
                 v = self.adata.var['variances'].values[gkeep]
                 v[v==0]=1
                 m = self.adata.var['means'].values[gkeep]*W[gkeep]
-                output = ut._pca_with_sparse(D_sub, npcs,mu = (m/v**0.5)[None,:], seed = seed)
+                no = (m/v**0.5) if preprocessing=='StandardScaler' else D_sub.mean(0).A.flatten()
+                output = ut._pca_with_sparse(D_sub, npcs,mu = (no)[None,:], seed = seed)
                 self.components = output['components']
                 g_weighted = output['X_pca']
 
@@ -1138,7 +1139,7 @@ class SAM(object):
             v = self.adata.var['variances'].values[gkeep]
             v[v==0]=1
             m = self.adata.var['means'].values[gkeep]*W[gkeep]
-            ns = m/v**0.5
+            ns = (m/v**0.5) if preprocessing=='StandardScaler' else D_sub.mean(0).A.flatten()
             if sp.issparse(D_sub):
                 g_weighted = D_sub.dot(self.components.T) - ns.flatten().dot(self.components.T)
             else:
